@@ -1,3 +1,6 @@
+/*jslint undef: true */
+/*global $: false, deform: false */
+
 (function() {
 
   deform.appendSequenceItem = function(node) {
@@ -5,9 +8,9 @@
     $oid_node = $(node).parent();
     $proto_node = $oid_node.children('.deformProto').first();
     $before_node = $oid_node.children('.deformSeqContainer').first().children('.deformInsertBefore');
-    min_len = parseInt($before_node.attr('min_len') || '0');
-    max_len = parseInt($before_node.attr('max_len') || '9999');
-    now_len = parseInt($before_node.attr('now_len') || '0');
+    min_len = parseInt($before_node.attr('min_len') || '0', 10);
+    max_len = parseInt($before_node.attr('max_len') || '9999', 10);
+    now_len = parseInt($before_node.attr('now_len') || '0', 10);
     if (now_len < max_len) {
       deform.addSequenceItem($proto_node, $before_node);
       deform.processSequenceButtons($oid_node, min_len, max_len, now_len + 1);
@@ -19,12 +22,9 @@
     var $lis, $ul;
     $ul = oid_node.children('.deformSeqContainer');
     $lis = $ul.children('.deformSeqItem');
-    $lis.find('.deformClosebutton').removeClass('deformClosebuttonActive');
-    oid_node.children('.deformSeqAdd').show();
-    if (now_len > min_len) {
-      $lis.find('.deformClosebutton').addClass('deformClosebuttonActive');
-    }
-    if (now_len >= max_len) return oid_node.children('.deformSeqAdd').hide();
+
+    $lis.children('.close').toggle(now_len > min_len);
+    oid_node.children('.deformSeqAdd').toggle(now_len < max_len);
   };
 
-}).call(this);
+}.call(this));
